# Generated by Django 5.2.6 on 2025-09-27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("competition", "0054_migrate_thumbnail_urls_to_binary"),
    ]

    operations = [
        # Remove foreign key constraints by altering the fields to remove the FK relationships
        # This allows test database cleanup to work while keeping the tables for now

        # Remove FK from RankTeam.club
        migrations.AlterField(
            model_name='rankteam',
            name='club',
            field=models.IntegerField(null=True, blank=True),
        ),

        # Remove FK from RankTeam.division
        migrations.AlterField(
            model_name='rankteam',
            name='division',
            field=models.IntegerField(null=True, blank=True),
        ),

        # Remove FK from RankPoints.team
        migrations.AlterField(
            model_name='rankpoints',
            name='team',
            field=models.IntegerField(null=True, blank=True),
        ),
    ]