"""[User Facing] Core definitions for the competition app.

This module exposes app metadata and is tightly coupled to the
tournamentcontrol project.
"""

default_app_config = "tournamentcontrol.competition.apps.CompetitionConfig"
